;----------------------------------------------------------------------------
; Notes on ROM calls
;----------------------------------------------------------------------------
; Function parameters are listed using the C language calling convention.
; Parameters are pushed onto the stack in reverse order.
;
; To clean up after the function has been called, pop all the values that
; were pushed. This can be done by adding a value to SP; this value is
; calculated by summing the sizes of all the parameters that were pushed.
;
; Unless otherwise specified, assume that D0-D2/A0-A1 are destroyed by any
; given ROM function upon return.
;
; Inside a block of English text, variables will be
; designated with surrounding braces {}.
;----------------------------------------------------------------------------
; char =  8-bit integer (byte)
; int  = 16-bit integer (word)
; long = 32-bit integer (longword)
;----------------------------------------------------------------------------

;----------------------------------------------------------------------------
; ROM_base specifies the beginning address of the ROM image that is
; currently being used. It may most notably be used for ROM dumps.
;----------------------------------------------------------------------------
tios::ROM_base			equ	tios@0025

;----------------------------------------------------------------------------
; ER_throwVar(WORD errorNum)
;
; Function: Restores the state previously saved by ER_catch, making
;           D0.W = {errorNum}
;
; Return: Never returns
;----------------------------------------------------------------------------
tios::ER_throwVar		equ	tios@000D

;----------------------------------------------------------------------------
; ER_catch(void *ErrorFrame)
;
; Function: Saves the state in {ErrorFrame}, which is a $38 byte structure.
;           The state consists of the values of A2-A7, D3-D7, and PC. It also
;           records a pointer to the previously saved state, which makes it a
;           linked list / stack.
;
; Return: D0.W = 0
;
; Note: If ER_throw is called later on, it simulates a return from the
;       previously called ER_catch, in which D0.W = the error code. The
;       processor must be in User mode for this to work properly.
;----------------------------------------------------------------------------
tios::ER_catch			equ	tios@0004

;----------------------------------------------------------------------------
; ER_success(void)
;
; Function: Pops the state previously saved by ER_catch off the stack.
;
; Return: nothing
;----------------------------------------------------------------------------
tios::ER_success		equ	tios@0005

;----------------------------------------------------------------------------
; ST_busy(int mode)
;
; Function: Switches to idle, busy, or paused. This indicator is displayed
;           in the status line. You must call update_status() for the change
;           to appear visually.
;
; Return: nothing
;
; mode=0 -> idle
; mode=1 -> busy
; mode=2 -> paused
;----------------------------------------------------------------------------
tios::ST_busy			equ	tios@000C

;----------------------------------------------------------------------------
; ST_redraw(void)
;
; Function: Updates the status line.
;
; Return: nothing
;----------------------------------------------------------------------------
tios::ST_redraw			equ	tios@0000

;----------------------------------------------------------------------------
; ST_message(char *message)
;
; Function: Displays {message} in the status line.
;
; Return: nothing
;----------------------------------------------------------------------------
tios::ST_message		equ	tios@0001

;----------------------------------------------------------------------------
; HeapFreeIndir(int *handle)
;
; Function: Deletes the allocated memory block {handle} and sets it to zero.
;
; Return: nothing
;----------------------------------------------------------------------------
tios::HeapFreeIndir		equ	tios@000B

;----------------------------------------------------------------------------
; HeapFree(int handle)
;
; Return: nothing
;
; Function: Deletes the allocated memory block {handle}.
;----------------------------------------------------------------------------
tios::HeapFree			equ	tios@0002

;----------------------------------------------------------------------------
; HeapAlloc(long size)
;
; Function: Allocates a memory handle.
;
; Return: success: D0.W = allocated handle
;         failure: D0.L = 0
;----------------------------------------------------------------------------
tios::HeapAlloc			equ	tios@0003

;----------------------------------------------------------------------------
; HeapAllocThrow(long size)
;
; Function: Allocates a memory handle, and does an ER_throw(ER_MEMORY) if
;           there's not enough RAM available.
;
; Return: D0.W = allocated handle
;----------------------------------------------------------------------------
tios::HeapAllocThrow		equ	tios@0022

;----------------------------------------------------------------------------
; HeapRealloc(int handle, long newsize)
;
; Function: Allocates or resizes a memory handle.
;
; Return: D0.W = allocated handle (successful)
;         D0.L = 0 (unsuccessful)
;
; Note: If {handle} is zero, a new handle will be
;       created. Otherwise, {handle} will be
;       reallocated to the new size.
;----------------------------------------------------------------------------
tios::HeapRealloc		equ	tios@000E

;----------------------------------------------------------------------------
; reset_link(void)
;
; Function: resets the link interface
;
; Return: nothing
;----------------------------------------------------------------------------
tios::reset_link		equ	tios@0006

tios::flush_link		equ	tios@0007

;----------------------------------------------------------------------------
; tx_free(void)
;
; Function: returns the number of free bytes in the link transmit buffer
;
; Return: D0.W = number of bytes
;----------------------------------------------------------------------------
tios::tx_free			equ	tios@0008

;----------------------------------------------------------------------------
; transmit(char *buffer, int num)
;
; Function: inserts {num} bytes from {buffer} into link transmit buffer
;
; Return: No error: D0.L = $00000000
;                   A0   = data + num
;         Error:    D0.B = $FF
;                   A0   = data
;
; {num} must be in the range [$01...$80]
;
; Note: An error occurs if {num} is out of range or if there is not enough
;       room in the transmit buffer to insert {num} bytes.
;----------------------------------------------------------------------------
tios::transmit			equ	tios@0009

;----------------------------------------------------------------------------
; receive(char *buffer, int num)
;
; Function: reads at most {num} bytes into {buffer} from link receive buffer
;
; Return:  D0.L = number of bytes read
;          A0 = buffer + (number of bytes read)
;----------------------------------------------------------------------------
tios::receive			equ	tios@000A

;----------------------------------------------------------------------------
; int sprintf(char *buffer, char *format[, argument, ...])
;
; Function: Uses {format} as a template to output a string to {buffer},
;           substituting arguments when '%' is found in {format}.
;
; Return: D0.W = number of bytes output
;
; For an explanation of format specifiers, please see a reference on the
; C programming language.
;----------------------------------------------------------------------------
tios::sprintf			equ	tios@000F

;----------------------------------------------------------------------------
; void vcbprintf(void func(char, void **), void **param, char *format,
;                void *va_list)
;
; Function: Virtual callback printf. Processes {format}, using {va_list} as
;           a pointer to its parameter list, calling {func}(char, {param})
;           to output each character.
;
; Return: nothing
;
; For an explanation of format specifiers, please see a reference on the
; C programming language.
;----------------------------------------------------------------------------
tios::vcbprintf			equ	tios@0027

;----------------------------------------------------------------------------
; DrawStrXY(int x, int y, char *string, int color)
;
; Function: prints {string} at {x,y} with current font
;
; Return: nothing
;----------------------------------------------------------------------------
tios::DrawStrXY			equ	tios@0010

;----------------------------------------------------------------------------
; DrawCharXY(int ch, int x, int y, int color, int what1, int what2, int what3)
;
; Function: prints {ch} at {x,y} with current font
;
; Return: nothing
;
; {what1} should be set to $00FF.
; {what2} should be set to $0000.
; {what3} should be set to $00FF.
;----------------------------------------------------------------------------
tios::DrawCharXY		equ	tios@0011

;----------------------------------------------------------------------------
; FontSetSys(int font)
;
; Function: sets the font used for printing text
;
; Return: D0.B = font before function was called
;----------------------------------------------------------------------------
tios::FontSetSys		equ	tios@0012

;----------------------------------------------------------------------------
; FontGetSys(int font)
;
; Return: D0.B = current font
;----------------------------------------------------------------------------
tios::FontGetSys		equ	tios@0026

tios::DrawTo			equ	tios@0013

tios::MoveTo			equ	tios@0014

tios::PortSet			equ	tios@0015

tios::PortRestore		equ	tios@0016

;----------------------------------------------------------------------------
; WinActivate(window *window)
;
; Function: Draws {window} as created by WinOpen()
;
; Return: nothing
;----------------------------------------------------------------------------
tios::WinActivate		equ	tios@0017

;----------------------------------------------------------------------------
; WinClose(window *window)
;
; Function: Replaces background and frees memory used by {window}
;
; Return: nothing
;----------------------------------------------------------------------------
tios::WinClose			equ	tios@0018

;----------------------------------------------------------------------------
; WinOpen(window *window, rect *rect, int flags[, char *title])
;
; Function: Creates a window descriptor at {window}.
;
; Return: success: D0.L = nonzero
;         failure: D0.L = zero
;----------------------------------------------------------------------------
tios::WinOpen			equ	tios@0019

;----------------------------------------------------------------------------
; void WinStrXY(window *window, int x, int y, char *string)
;
; Function: prints {string} to {window} at {x,y}
;
; Return: nothing
;----------------------------------------------------------------------------
tios::WinStrXY			equ	tios@001A

tios::MenuPopup			equ	tios@001E

tios::MenuBegin			equ	tios@001F

tios::MenuOn			equ	tios@0020

;----------------------------------------------------------------------------
; void *SF_font: Pointer to ROM font table
;
; SF_font+$0000 = small font (height = 5, width = variable)
; SF_font+$0600 = medium font (height = 8, width = 6)
; SF_font+$0E00 = large font (height = 10, width = 8)
;----------------------------------------------------------------------------
tios::SF_font			equ	tios@0021

;----------------------------------------------------------------------------
; int strcmp(char *s1, char *s2)
;
; Function: Compares two strings.
;
; Return: D0.W < 0  if  s1 < s2
;         D0.W = 0  if  s1 = s2
;         D0.W > 0  if  s1 > s2
;----------------------------------------------------------------------------
tios::strcmp			equ	tios@0023

;----------------------------------------------------------------------------
; SYM_ENTRY *FindSymEntry(HANDLE symlist, BYTE *name)
;
; Function: Finds a symbol called {name} in a symbol list pointed to by
;           the handle {symlist}.
;
; Return: A0.L = pointer to symbol entry, NULL if symbol not found
;
; Note: If you pass {symlist} = FOLDER_LIST_HANDLE, then the function will
;       search for the folder {name}. You may then use the returned handle
;       value to call the function again, this time searching for a variable
;       in that folder.
;----------------------------------------------------------------------------
tios::FindSymEntry		equ	tios@0024

;****************************************************************************
; defines

tios::NULL		equ	0
tios::H_NULL		equ	0

; codes for ST_busy()
ACTIVITY_IDLE		equ	0
ACTIVITY_BUSY		equ	1
ACTIVITY_PAUSED		equ	2

; codes for ER_throw()
tios::ER_STOP		equ	2
tios::ER_DIMENSION	equ	230
tios::ER_MEMORY		equ	670
tios::ER_MEMORY_DML	equ	810

; tags
tios::UNDEFINED_TAG	equ	$2A
tios::LIST_TAG		equ	$D9
tios::MATRIX_TAG	equ	$DB
tios::END_TAG		equ	$E5

tios::STOF_ESI		equ	$4000
tios::STOF_HESI		equ	$4003

;****************************************************************************
; structures

tios::SYM_ENTRY.name	equ	0	; name of symbol
tios::SYM_ENTRY.flags	equ	8	; flags
tios::SYM_ENTRY.hVal	equ	10	; handle of symbol

;****************************************************************************
; RAM addresses

tios::main_lcd		equ	tios@001C

tios::kb_vars		equ	tios@001B

tios::ST_flags		equ	tios@001D

LCD_MEM			equ	tios::main_lcd

tios::OSOnBreak		equ	tios::main_lcd+$0F02	; byte

APD_INIT		equ	tios::main_lcd+$0F10	; long (integer)
APD_TIMER		equ	tios::main_lcd+$0F14	; long (integer)
APD_FLAG		equ	tios::main_lcd+$0F42	; word

LINK_TX_BUF		equ	tios::main_lcd+$0FA8
LINK_RX_BUF		equ	tios::main_lcd+$1030

tios::estack_max_index	equ	tios::main_lcd+$1260
tios::top_estack	equ	tios::main_lcd+$1264

tios::bottom_estack	equ	tios::main_lcd+$126A

tios::NG_code_handle	equ	tios::main_lcd+$1270

tios::ERR_code_handle	equ	tios::main_lcd+$127E

tios::NG_control	equ	tios::main_lcd+$12B6

tios::EV_handler	equ	tios::main_lcd+$1360	; long (pointer)
tios::EV_runningApp	equ	tios::main_lcd+$1364
tios::EV_currentApp	equ	tios::main_lcd+$1366
tios::EV_appA		equ	tios::main_lcd+$1368
tios::EV_appB		equ	tios::main_lcd+$136A

tios::EV_errorCode	equ	tios::main_lcd+$136E

tios::FirstWindow	equ	tios::main_lcd+$1810

tios::CurTE		equ	tios::main_lcd+$184C

tios::Heap		equ	tios::main_lcd+$1902	; long (pointer)

tios::SymTempFolCount	equ	tios::main_lcd+$1940	; word (integer)

FOLDER_LIST_HANDLE	equ	tios::main_lcd+$194C	; word (handle)

tios::DefTempHandle	equ	tios::main_lcd+$1950	; word (handle)

STATUS_LINE		equ	tios::ST_flags		; long

;****************************************************************************
; useful macros

tios::DEREF	macro	; Dn,An
	lsl.w	#2,\1
	move.l	tios::Heap,\2
	move.l	0(\2,\1.w),\2
		endm

tios::ER_throw	macro
	dc.w	$A000+\1
		endm

;****************************************************************************
